==> HostCMS.Free_6.7.tar.gz: modules/affiliate/plan/i18n/ru.php <==
<?php
/**
 * Affiliates.
 *
 * @package HostCMS
 * @subpackage Affiliate
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2017 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'affiliate_title' => 'Партнерские программы',
	'model_name' => 'Партнерские программы',
	'affiliate_menu_title' => 'Партнерские программы',
	'affiliate_menu_title_add' => 'Добавить',
	'affiliate_form_add' => 'Добавление партнерской программы',
	'affiliate_form_edit' => 'Редактирование партнерской программы',
	'name' => '<acronym title="Название партнерской программы">Название</acronym>',
	'description' => '<acronym title="Описание партнерской программы">Описание</acronym>',
	'site_id' => '<acronym title="Сайт, на котором будет доступна партнерская программа">Сайт</acronym>',
	'active' => '<acronym title="Флажок активности партнерской программы">Активность</acronym>',
	'siteuser_group_id' => '<acronym title="Группа пользователей сайта, которой будет доступна партнерская программа">Группа пользователей сайта</acronym>',
	'datetime' => '<acronym title="Дата последнего изменения партнерской программы">Дата последнего изменения</acronym>',
	'min_count_of_items' => '<acronym title="Минимальное число товаров, которое пользователь должен купить за один раз, чтобы получить начисления по партнерской программе">Минимальное число товаров в заказе</acronym>',
	'min_amount_of_items' => '<acronym title="Минимальная сумма в валюте магазина, на которую пользователь сайта должен приобрести товаров за один раз, чтобы получить начисления по партнерской программе">Минимальная сумма в валюте магазина</acronym>',
	'include_delivery' => '<acronym title="Учитывать ли доставку товара, при просчете комиссии аффилиату">Доставка товара</acronym>',
	'id' => 'Идентификатор',
	'edit_success' => 'Партнерская программа успешно добавлена',
	'edit_error' => 'Ошибка добавления информации о партнерской программе',
	'markDeleted_success' => 'Информация о партнерской программе успешно удалена',
	'affiliate_assotiation_form_title' => 'Партнерские программы, доступные магазину "%s"',
	'changeStatus_success' => "Информация успешно изменена",
	'changeStatusOn_success' => "Информация успешно изменена",
	'changeStatusOff_success' => "Информация успешно изменена",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);

==> HostCMS.Free_7.0.tar.gz: modules/affiliate/plan/i18n/ru.php <==
<?php

return array(
	'affiliate_title' => 'Партнерские программы',
	'model_name' => 'Партнерские программы',
	'affiliate_menu_title' => 'Партнерские программы',
	'affiliate_menu_title_add' => 'Добавить',
	'affiliate_form_add' => 'Добавление партнерской программы',
	'affiliate_form_edit' => 'Редактирование партнерской программы',
	'name' => 'Название',
	'description' => 'Описание',
	'site_id' => '<acronym title="Сайт, на котором будет доступна партнерская программа">Сайт</acronym>',
	'active' => 'Активность',
	'siteuser_group_id' => '<acronym title="Группа клиентов, которой будет доступна партнерская программа">Группа клиентов</acronym>',
	'datetime' => 'Дата последнего изменения',
	'min_count_of_items' => '<acronym title="Минимальное число товаров, которое пользователь должен купить за один раз, чтобы получить начисления по партнерской программе">Минимальное число товаров в заказе</acronym>',
	'min_amount_of_items' => '<acronym title="Минимальная сумма в валюте магазина, на которую пользователь сайта должен приобрести товаров за один раз, чтобы получить начисления по партнерской программе">Минимальная сумма в валюте магазина</acronym>',
	'include_delivery' => '<acronym title="Учитывать ли доставку товара, при просчете комиссии аффилиату">Доставка товара</acronym>',
	'id' => 'Идентификатор',
	'edit_success' => 'Партнерская программа успешно добавлена',
	'edit_error' => 'Ошибка добавления информации о партнерской программе',
	'markDeleted_success' => 'Информация о партнерской программе успешно удалена',
	'affiliate_assotiation_form_title' => 'Партнерские программы, доступные магазину "%s"',
	'changeStatus_success' => "Информация успешно изменена",
	'changeStatusOn_success' => "Информация успешно изменена",
	'changeStatusOff_success' => "Информация успешно изменена",
	'delete_success' => 'Элемент удален!',
	'undelete_success' => 'Элемент восстановлен!',
);
